#' Pipe operator
#'
#' See \code{\link[magrittr]{\%>\%}} for more details.
#'
#' @name %>%
#' @rdname pipe
#' @keywords internal
#' @export
#' @importFrom magrittr %>%
#' @usage lhs \%>\% rhs
NULL


#' @importFrom tensorflow tf
#' @export
tensorflow::tf

#' @importFrom tensorflow shape
#' @export
tensorflow::shape

#' @importFrom tensorflow install_tensorflow
#' @export
tensorflow::install_tensorflow

#' @importFrom generics fit
#' @export
generics::fit

#' @importFrom reticulate as_iterator
#' @export
reticulate::as_iterator

#' @importFrom reticulate iter_next
#' @export
reticulate::iter_next


#' @importFrom reticulate iterate
#' @export
reticulate::iterate
